import codecommit = require('@aws-cdk/aws-codecommit');
import codepipeline = require('@aws-cdk/aws-codepipeline');
/**
 * Construction properties of the {@link PipelineSource CodeCommit source CodePipeline Action}.
 */
export interface PipelineSourceProps {
    /**
     * The name of the source's output artifact. Output artifacts are used by CodePipeline as
     * inputs into other actions.
     */
    artifactName: string;
    /**
     * The CodeCommit repository.
     */
    repository: codecommit.RepositoryRef;
    /**
     * @default 'master'
     */
    branch?: string;
    /**
     * Whether or not AWS CodePipeline should poll for source changes
     *
     * @default true
     */
    pollForSourceChanges?: boolean;
}
/**
 * CodePipeline Source that is provided by an AWS CodeCommit repository.
 */
export declare class PipelineSource extends codepipeline.Source {
    constructor(parent: codepipeline.Stage, name: string, props: PipelineSourceProps);
}
